@@ -2,15 +2,10 @@ package Astro::IRAF::CL;
 use strict;
 use warnings;
 
-$SIG{INT} = sub {die}; # Without this DESTROY() does not get called 
-		       # when ctrl-c is used for some reason.
-
 use Carp;
 use vars qw($VERSION $AUTOLOAD $TIMEOUT);
 
-$VERSION = '0.2.0';
-
-use Fcntl qw(:DEFAULT);
+$VERSION = '0.1';
 
 use Cwd;
 use Expect 1.15;
@@ -43,7 +38,7 @@ sub new{
 
   $self->{'packages'}        = []; # For loading/unloading packages.
   $self->{'command_history'} = [];
-  $self->{'dead'}            = 1; # It is dead until the CL is running.
+  $self->{'dead'}            = 0;
 
   $self->{'session'} = $self->_startup;
 
@@ -100,37 +95,16 @@ sub _get_iraf_start{
   return $startdir;
 }
 
-sub _lock_startdir{
-  my $self = shift @_;
-
-  sysopen(STARTDIR,"$self->{'iraf_start'}/Astro-IRAF-CL.LOCK",O_WRONLY|O_CREAT|O_EXCL) or croak "\nERROR: Could not get a lock on $self->{'iraf_start'}: $!\n\nThis IRAF start directory is already in use by another Astro::IRAF::CL object,\nyou must specify a different starting position via the iraf_start parameter.\n\nDied";
-
-  $self->{'STARTDIR_FH'} = *STARTDIR;
-
-}
-
-sub _unlock_startdir{
-  my $self = shift @_;
-
-  close ($self->{'STARTDIR_FH'}) or croak "could not close lock FH";
-  unlink "$self->{'iraf_start'}/Astro-IRAF-CL.LOCK";
-
-}
-
 sub _startup{
   my $self = shift @_;
 
-  $self->_lock_startdir;
-
-  chdir $self->{'iraf_start'} ||croak "Could not cd to $self->{'iraf_start'}";
+  chdir $self->{'iraf_start'} || croak "Could not cd to $self->{'iraf_start'}";
 
   my $t = Expect->spawn('cl') || croak "Cannot spawn CL: $!";
 
   $t->expect(30,'-re',$self->{'cl_prompt'});
   croak "Did not get CL prompt after starting up" if $t->error;
 
-  $self->{'dead'} = 0; # It is now alive.
-
   my $output = $t->before();
   my @output = split /\n/,$output;
   if ($self->{'display_startup'}){
@@ -377,24 +351,6 @@ sub set_log{
 
 ## Error handlers.
 
-sub cl_warning_handler{
-  my ($self,$command,$handler) = @_;
-
-  my $session = $self->{'session'};
-  $session->expect($TIMEOUT,'-re',$self->{'cl_prompt'});
-
-  my $error = $session->before();
-
-  print STDERR "The command $command encountered a CL Warning:\n\n$error\n";
-
-  if (defined $handler){
-    print STDERR "Passing off to warning handler\n";
-    $handler->($self);
-  }
-
-  return;
-}
-
 sub cl_error_handler{
   my ($self,$command,$handler) = @_;
 
@@ -634,11 +590,10 @@ sub exec{
 
   my $timeout = defined $params{'timeout'} ? $params{'timeout'} : undef;
   my $error_handler   = $params{'error_handler'}   || undef;
-  my $warning_handler = $params{'warning_handler'} || undef;
   my $death_handler   = $params{'death_handler'}   || undef;
   my $timeout_handler = $params{'timeout_handler'} || undef;
 
-  my ($q_timeout,$q_eof,$q_error,$q_warning,$not_available) = (0,0,0,0,0);
+  my ($q_timeout,$q_eof,$q_error,$q_warning,$not_available) = (0,0,0,0);
 
   my @output;
 
@@ -703,16 +658,13 @@ sub exec{
     $t->expect($timeout,
 	       [timeout => sub {&timeout_handler($self,$command,$timeout,
 						 $timeout_handler);
-				$q_timeout = 1; exp_continue}],
+				$q_timeout = 1}],
 	       [eof     => sub {&eof_handler($self,$command,
 					     $death_handler);
-				$q_eof = 1; exp_continue}],
-	       '-re','^Warning:',sub {&cl_warning_handler($self,$command,
-							  $warning_handler);
-				    $q_warning = 1; exp_continue},
+				$q_eof = 1}],
 	       '-re','^ERROR:',sub {&cl_error_handler($self,$command,
 						      $error_handler);
-				    $q_error = 1; exp_continue},
+				    $q_error = 1},
 	       '-ex','No help available for',sub{print STDERR "No help available for $helpname\n";
 						 $not_available = 1;
 					       },
@@ -823,8 +775,6 @@ sub end{
 
   $t->soft_close();
 
-  $self->_unlock_startdir;
-
   $self->{'dead'} = 1;
 }
 
